@@ -8,7 +8,7 @@ import os
 from PIL import Image
 
 from sensenet.constants import CATEGORICAL, IMAGE, BOUNDING_BOX
-from sensenet.constants import NUMERIC_INPUTS, WARP, CROP
+from sensenet.constants import NUMERIC_INPUTS, WARP, CROP, PAD
 
 from sensenet.accessors import get_image_shape
 from sensenet.layers.extract import extract_layers_list
@@ -164,7 +164,7 @@ def test_yolov4():
 
 
 def test_empty():
-    detector = create_image_model("tinyyolov4", None)
+    detector = create_image_model("tinyyolov4", {"rescale_type": PAD})
     image_path = os.path.join(TEST_IMAGE_DATA, "black.png")
     image = load_points([{"type": IMAGE, "index": 0}], [[image_path]])
     boxes, scores, classes = detector.predict(image)
@@ -175,7 +175,7 @@ def test_empty():
 
 
 def test_scaling():
-    detector = create_image_model("tinyyolov4", None)
+    detector = create_image_model("tinyyolov4", {"rescale_type": PAD})
     image_path = os.path.join(TEST_IMAGE_DATA, "strange_car.png")
     image = load_points([{"type": IMAGE, "index": 0}], [[image_path]])
     boxes, scores, classes = detector.predict(image)
